/**************************************************************************
** 
** File name   : bstrap_chap6.do
** Date        : July 18, 2008
** Author      : Christina J. Schneider 
** Purpose     : Replicates Table 6.1 and gives the point estimates 
** Requires    : dyads.dta
** Output      : bstrap_chap6
** Info        : README
**
**************************************************************************/

version 10.0
#delimit ;

*Specify working directory

drop _all;
program drop _all;
set more off;

qui log;
loc logopen = r(status);
if "`logopen'" == "on" {; log close; };

set logtype text;
log using bstrap_chap6.log, replace;
di "$S_DATE $S_TIME";

use dyads, clear;

loc demand_fmw = "bipn_eu100 distance foreign erwerbindo erwerbindn unempln unemplo";
loc demand_csp = "bipn_eu100 fundo sizen erwerbindn erwerblandn contribution";
loc demand_cap = "totagrn totagro sizen contribution";

/*
** called by the bootstrap as the estimation command
*/
program define bstrap_area, eclass;
    syntax varlist, DEMAND(varname) DISCR(varname) AREA(name);
    loc discrimination_model "ceiling importfromeu share_exp perccouncil_change";

    quietly {;
        probit `demand' `varlist', cluster(oldmembers);
        predict prob_`area', pr;
        probit `discr' prob_`area' `discrimination_model', cluster(oldmember);
        predict prob_discr, pr;
        gen pred_discr = (prob_discr >= .5);
        tabulate discr pred_discr, matcell(freqs);

        /* what perecent of predictions was correct */
        ereturn scalar pctok = (freqs[1,1] + freqs[2,2]) / r(N);

        /* of predicted no's, how many were correct */
        ereturn scalar pctnok = freqs[1,1] / (freqs[1,1] + freqs[2,1]);

        /* of predicted yes's, how many were correct */
        ereturn scalar pctyok = freqs[2,2] / (freqs[2,2] + freqs[1,2]);

        drop prob_`area' prob_discr pred_discr;
    };
end;


loc reps = 1000;
loc seed = 160773;

bootstrap _b pctok=(e(pctok)) pctnok=(e(pctnok)) pctyok=(e(pctyok))
      , reps(`reps') nodots saving(bstrap_fmw, replace) seed(`seed')
      : bstrap_area `demand_fmw', area(fmw) demand(demand_fmw) discr(discr_fmw);
bootstrap _b pctok=(e(pctok)) pctnok=(e(pctnok)) pctyok=(e(pctyok))
      , reps(`reps') nodots saving(bstrap_csp, replace) seed(`seed')
      : bstrap_area `demand_csp', area(csp) demand(demand_csp) discr(discr_csp);
bootstrap _b pctok=(e(pctok)) pctnok=(e(pctnok)) pctyok=(e(pctyok))
      , reps(`reps') nodots saving(bstrap_cap, replace) seed(`seed')
      : bstrap_area `demand_cap', area(cap) demand(demand_cap) discr(discr_cap);

log close;
set more on;
