/**************************************************************************
** 
** File name   : make_dyads.do
** Date        : July 18, 2008
** Author      : Christina J. Schneider 
** Purpose     : Creates working dataset from original 
** Requires    : replication_final.dta
** Output      : dyads.dta 
**
**************************************************************************/


version 10.0
#delimit ;

use replication_final, clear;

/* create member-candidate dyad dataset 
** we have policy dyads but want just dyads with policies variables w/n dyad
*/
local varlist = "bipn_eu100 distance foreign erwerbindo erwerbindn unempln unemplo totagrn totagro sizen contribution fundo erwerblandn oldmember expbip pop65perc";
local keys = "freedomofmovement agriculture structuralfunds";
local newvars = "ceiling importfromeu share_exp perccouncil_change polityivnew enlargementround";
local genvars = "discr_cap discr_csp discr_fmw";

rename demdis_cap demand_cap;
rename demdis_sf  demand_csp;
rename demdis_fm  demand_fmw;

gen discr_cap = (disat==1 & agriculture==1);
gen discr_csp = (disat==1 & structuralfunds==1);
gen discr_fmw = (disat==1 & freedomofmovement==1);

keep `varlist' demand_cap demand_csp demand_fmw `keys' `genvars' `newvars';

preserve;
keep if freedomofmovement==1;
drop `keys' discr_cap discr_csp;
sort `varlist';
save fmw, replace;
restore;

preserve;
keep if agriculture==1;
drop `keys' discr_fmw discr_csp;
sort `varlist';
save cap, replace;
restore;

preserve;
keep if structuralfunds==1;
drop `keys' discr_fmw discr_cap;
sort `varlist';
save csp, replace;
restore;

use fmw, clear;
sort `varlist';
merge `varlist' using cap csp, unique;
gen demand = (demand_cap==1 | demand_csp==1 | demand_fmw==1);
gen discr = (discr_cap==1 | discr_csp==1 | discr_fmw==1);
drop _merge*;
save dyads, replace;
