/**************************************************************************
** 
** File name   : probit_chap5.do
** Date        : July 18, 2008
** Author      : Christina J. Schneider 
** Purpose     : Replicates the Probit Models in chapter 5 "Demand for Compensation" 
**			for each policy area
** Requires    : replication_final.dta 
** Output      : probit_chap5.log
** Info        : README
**
**************************************************************************/

version 10.0
#delimit ;

set more off;

* specify working directory
* use replication_final.dta;

log using probit_chap5, replace;



/* _________________________Free Movement of Workers _________________________________ */

sum demdisdum bipn_eu100  distance foreign erwerbindo erwerbindn unempln unemplo expbip polityivnew 
	contribution pop65perc sizen if  freedomofmovement==1;

/*Model 1*/
probit  demdisdum bipn_eu100  distance foreign erwerbindo erwerbindn unempln unemplo if  freedomofmovement==1, cluster(oldmembers);

/*Model 2*/
probit  demdisdum bipn_eu100  distance foreign erwerbindo erwerbindn unempln unemplo expbip polityivnew contribution pop65perc if  freedomofmovement==1, cluster(oldmembers);

/*Model 3*/
probit  demdisdum bipn_eu100  distance foreign erwerbindo erwerbindn unempln unemplo sizen if  freedomofmovement==1, cluster(oldmembers);


/*______________________ Common Agricultural Policies_________________________________*/


sum demdisdum totagrn totagro   sizen contribution erwerblandn bipn_eu100 expbip polityivnew ceiling_cap 
	if  agriculture==1;

/*Model 1*/
probit demdisdum  totagrn totagro sizen contribution if  agriculture==1,cluster (oldmember);

/*Model 2*/
probit demdisdum totagrn totagro   sizen contribution erwerblandn bipn_eu100 expbip polityivnew 
	if  agriculture==1,cluster (oldmember);

/*Model 3*/
probit demdisdum  totagrn totagro  ceiling_cap contribution if  agriculture==1,cluster (oldmember);


/*______________________ Structural Funds_________________________________________________*/

sum demdisdum  bipn_eu100  fundo sizen erwerbindn erwerblandn contribution expbip polityivnew cutfund_struc 
	if structuralfunds==1;


/*Model 1*/
probit demdisdum  bipn_eu100 fundo sizen erwerbindn erwerblandn contribution  if structuralfunds==1, cluster(oldmember); 

/*Model 2*/
probit demdisdum  bipn_eu100  fundo sizen erwerbindn erwerblandn contribution expbip polityivnew 
	if structuralfunds==1, cluster(oldmember); 

/*Model 3*/
probit demdisdum  bipn_eu100  fundo erwerbindn erwerblandn contribution expbip polityivnew cutfund_struc 
	if structuralfunds==1, cluster(oldmember); 


/*______________________SURE MODELS___________________________________________________*/


mvprobit (demdis_fm = bipn_eu100  distance foreign erwerbindo erwerbindn unempln unemplo) 
		(demdis_cap  = totagrn totagro sizen contribution)
			(demdis_sf  bipn_eu100 = fundo sizen erwerbindn erwerblandn contribution) 
				if  freedomofmovement==1, cluster(oldmembers);
mvprobit (demdis_fm bipn_eu100  distance foreign erwerbindo erwerbindn unempln unemplo expbip polityivnew 
		contribution pop65perc)(demdis_cap totagrn totagro sizen contribution erwerblandn bipn_eu100 expbip 
			polityivnew)(demdis_sf  bipn_eu100  fundo sizen erwerbindn erwerblandn contribution expbip polityivnew) 
				if structuralfunds==1, cluster(oldmember);
mvprobit (demdis_fm bipn_eu100  distance foreign erwerbindo erwerbindn unempln unemplo sizen)
		(demdis_cap  totagrn totagro  ceiling_cap contribution) 
			(demdis_sf  bipn_eu100  fundo erwerbindn erwerblandn contribution expbip polityivnew cutfund_struc) 
				if structuralfunds==1, cluster(oldmember); 



log close;
exit;
